@@ -107,6 +107,7 @@ class ConformanceArtefacts:
 
         # solve the formulas
         wncf = self.__createWncf(initialisationFormulas, distanceFormula, MULTI_ALIGNMENT)
+
         self.__solveWncf(wncf)
         return 0
 
@@ -341,6 +342,20 @@ class ConformanceArtefacts:
         else :
             raise Exception("Not developed for multi-alignment.")
 
+    def getMaxDistanceToRun(self):
+        aa = self.getRun()
+        while 'w' in aa:
+            aa.remove('w')
+        all = []
+        if self.__distance_type==EDIT_DISTANCE:
+            for l in self.__traces:
+                all.append(levenshtein(aa,l))
+        if self.__distance_type==HAMMING_DISTANCE:
+            for l in self.__traces:
+                all.append(hamming(aa,l))
+        return max(all)
+
+
     def getRealSizeOfRun(self):
         '''
         As we complete run with "wait" transition, we need the real size of the run
